==> sensei-image-api-1.0.3.tgz: package/src/modules/14reasons.js <==
const superagent = require('superagent');
const fs = require('fs');
const sharp = require('sharp');

module.exports = async (req, res) => {
    if (!req.query.url) {
        res.setHeader('Content-Type', 'application/json');
        res.send(JSON.stringify({
            error: 'URL is required!'
        }))
        return;
    }
    let url = req.query.url;
    if (!url.includes('http') && !url.includes('.')) {
        res.send(JSON.stringify({
            error: 'A valid URL must be provided!'
        }))
        return;
    }

    if ((!url.toLowerCase().includes('.png')) && (!url.toLowerCase().includes('.gif')) && (!url.toLowerCase().includes('.jpg')) && (!url.toLowerCase().includes('.jpeg'))) return res.send(JSON.stringify({
        error: 'This is not a valid image!'
    }))


    let image = await superagent.get(req.query.url).catch(err => {
        if (err) return res.send(JSON.stringify({
            error: err
        }))
    })
    let img = await sharp(image.body).resize(780, 497).max().toBuffer();
    let reasons = await sharp('./images/14reasons.png').toBuffer();

    sharp(reasons)
        .overlayWith(img, { top: 350, left: 0 })
        .toBuffer((err, data, info) => {
            if (err) {
                res.setHeader('Content-Type', 'application/json');
                res.send(JSON.stringify({
                    error: err
                }));
                return;
            }
            res.setHeader('Content-Type', 'image/png'); res.end(data)
        });
};

==> sensei-image-api-1.1.0.tgz: package/src/modules/14reasons.js <==
const superagent = require('superagent');
const fs = require('fs');
const sharp = require('sharp');

module.exports = async (req, res) => {
    if (!req.query.url) {
        res.setHeader('Content-Type', 'application/json');
        res.send(JSON.stringify({
            error: 'URL is required!'
        }))
        return;
    }
    let url = req.query.url;
    if (!url.includes('http') && !url.includes('.')) {
        res.send(JSON.stringify({
            error: 'A valid URL must be provided!'
        }))
        return;
    }

    if ((!url.toLowerCase().includes('.png')) && (!url.toLowerCase().includes('.gif')) && (!url.toLowerCase().includes('.jpg')) && (!url.toLowerCase().includes('.jpeg'))) return res.send(JSON.stringify({
        error: 'This is not a valid image!'
    }))


    let image = await superagent.get(req.query.url).catch(err => {
        if (err) return res.send(JSON.stringify({
            error: err
        }))
    })
    let img = await sharp(image.body).resize(780, 497).max().toBuffer();
    let reasons = await sharp(__dirname + '/images/14reasons.png').toBuffer();

    sharp(reasons)
        .overlayWith(img, { top: 350, left: 0 })
        .toBuffer((err, data, info) => {
            if (err) {
                res.setHeader('Content-Type', 'application/json');
                res.send(JSON.stringify({
                    error: err
                }));
                return;
            }
            res.setHeader('Content-Type', 'image/png'); res.end(data)
        });
};
